//-----------------------------------------------------------------------------
//! \file       test_file.h
//! \brief      Definition of the class DemoClass
//! \par
//! \author     L.F. Kuiper
//! \copyright  (c) 2005, HITT Traffic B.V.
//!
//! $Id$
// 
// $Log$
//-----------------------------------------------------------------------------


#ifndef __TEST_FILE_H__
#define __TEST_FILE_H__




//-----------------------------------------------------------------------------
//! \brief      Abstract class for use with MessageDlg.
//!
//!             This class shall be a base class for all classes that want to display a
//!             warning, informational or critical message by means of the MessageDlg class.
//!
//!             MessageDlg is a class with similar functionality as the QMessageBox class. MessageDlg is created because QMessageBox is a modal dialog with a normal window border. The major drawback of such a border is that the when the left mouse is pressed on the title bar no events will be handle any more (no comms events either) until the mouse is released again. This is a safety issue and must be omitted.
//!             Therefor MessageDlg is created and is derived from AInteractWnd. Drawback of this approach is that the dialog is not modal.
//!             To remove this drawback the following must be taken into account:
//!             
//!             When a class wants to show a message by means of the MessageDlg, it must be derived from DemoClass. By doing this a port connection will be made with the MessageDlg at the moment of instantiation of MessageDlg. This connection is necessary because in the MessageDlg several buttons can be placed ( Ok, Cancel, Yes, No, Abort, Retry and Ignore) and the calling class has to know which of the buttons is pressed. This is done by calling messageDlgReply( int id, int reply). This is a method of DemoClass and must be overloaded in the calling class.
//!             Because the MessageDlg is a non-modal dialog, it is possible to neglect the message dialog, keep it open and continue working. Therefor it is necessary to check, in some cases,  if the message dialog is still open or not. This is done by calling  messageDlgShown(). This method of DemoClass returns true if the MessageDlg is still open and it sounds a signal.
//!             When one of the buttons of the message dialog is pressed messageDlgReply() is called. In this method the messageDlgShown flag can be cleared by calling messageDlgShown( false );
//!
//!             
//!             The next example contains no valid code, it is just ilustrative.
//!             
//!\anchor start Start of the code example:
//!             Include file:
//!             <pre><tt>
//!<b>1. #include <widgets/DemoClass.h></b>
//!
//!2. class IdentificationDlg : public DemoClass
//!3. {
//!\anchor public // public part
//!4. public:
//!<b>5.   enum MessageOriginId</b>
//!<b>6.   {</b>
//!<b>7.     EmptyFields        = 1,</b>
//!<b>8.     ApplyCorrectValues = 2,</b>
//!<b>9.     OkCorrectValues    = 3</b>
//!<b>10.   };</b>
//!11.   IdentificationDlg();
//!12.   virtual ~IdentificationDlg();
//!                     
//!13.   virtual void ok();
//!14.   virtual void doOk();
//!15.   virtual void cancel();
//!16.   virtual void apply();
//!17.   virtual void doApply();
//!18.   virtual void reset();
//!
//!<b>19.   bool checkEmptyFields  ( MessageOriginId originId );</b>
//!<b>20.   bool checkCorrectValues( MessageOriginId originId );</b>
//!
//!<b>21.   virtual void messageDlgReply( int id, int reply);</b>
//!22. };
//!            \ref start "To begin of source code from inside pre-tags"
//!            \ref public "To public part from inside pre-tags"
//!            </tt></pre>
//!            \ref start "To begin of source code from outside pre-tags"
//!            \ref public "To public part from outside pre-tags"
//!             
//!             What do we see here:
//!             \li Line 1: the include file of the base class. 
//!             \li Line 2: The class must be derived from DemoClass.
//!             \li Line 5: A list of id's that will be used to indicate the origin of the MessageDlg.
//!             \li Line 19 and 20: See source file
//!             \li Line 21: This is a method of DemoClass that must be implemented in the derived class.
//!             
//!             
//-----------------------------------------------------------------------------
class DemoClass

{

public:

  //-----------------------------------------------------------------------------
  //!             Constructor
  //!
  //-----------------------------------------------------------------------------
  DemoClass();
  //-----------------------------------------------------------------------------
  //!             Destructor
  //!
  //-----------------------------------------------------------------------------
  virtual ~DemoClass();

  //-----------------------------------------------------------------------------
  //!             Initializes the MessageDlgCaller. Reads the settings from messagedlg.xml
  //!
  //-----------------------------------------------------------------------------
  virtual void initCaller();

private:
};



#endif //__TEST_FILE_H__
